==> lambdas3-1.174.0-sources.jar: software/amazon/awsconstructs/services/lambdas3/LambdaToS3.java <==
package software.amazon.awsconstructs.services.lambdas3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-01T20:13:04.277Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdas3.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-s3.LambdaToS3")
public class LambdaToS3 extends software.amazon.awscdk.core.Construct {

    protected LambdaToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToS3(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdas3.LambdaToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder();
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the bucket.
         * <p>
         * Default: - S3_BUCKET_NAME
         * <p>
         * @return {@code this}
         * @param bucketEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the bucket. This parameter is required.
         */
        public Builder bucketEnvironmentVariableName(final java.lang.String bucketEnvironmentVariableName) {
            this.props.bucketEnvironmentVariableName(bucketEnvironmentVariableName);
            return this;
        }

        /**
         * Optional bucket permissions to grant to the Lambda function.
         * <p>
         * One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param bucketPermissions Optional bucket permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder bucketPermissions(final java.util.List<java.lang.String> bucketPermissions) {
            this.props.bucketPermissions(bucketPermissions);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps Optional user provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdas3.LambdaToS3 build() {
            return new software.amazon.awsconstructs.services.lambdas3.LambdaToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdas3-2.2.0-sources.jar: software/amazon/awsconstructs/services/lambdas3/LambdaToS3.java <==
package software.amazon.awsconstructs.services.lambdas3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-20T16:23:32.015Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdas3.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-s3.LambdaToS3")
public class LambdaToS3 extends software.constructs.Construct {

    protected LambdaToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToS3(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getS3BucketInterface() {
        return software.amazon.jsii.Kernel.get(this, "s3BucketInterface", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdas3.LambdaToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder();
        }

        /**
         * Optional name for the S3 bucket environment variable set for the Lambda function.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param bucketEnvironmentVariableName Optional name for the S3 bucket environment variable set for the Lambda function. This parameter is required.
         */
        public Builder bucketEnvironmentVariableName(final java.lang.String bucketEnvironmentVariableName) {
            this.props.bucketEnvironmentVariableName(bucketEnvironmentVariableName);
            return this;
        }

        /**
         * Optional bucket permissions to grant to the Lambda function.
         * <p>
         * One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param bucketPermissions Optional bucket permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder bucketPermissions(final java.util.List<java.lang.String> bucketPermissions) {
            this.props.bucketPermissions(bucketPermissions);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps Optional user provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps Optional user provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props for the S3 Logging Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param loggingBucketProps Optional user provided props to override the default props for the S3 Logging Bucket. This parameter is required.
         */
        public Builder loggingBucketProps(final software.amazon.awscdk.services.s3.BucketProps loggingBucketProps) {
            this.props.loggingBucketProps(loggingBucketProps);
            return this;
        }

        /**
         * Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
         * <p>
         * Enabling Access Logging is a best practice.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param logS3AccessLogs Whether to turn on Access Logs for the S3 bucket with the associated storage costs. This parameter is required.
         */
        public Builder logS3AccessLogs(final java.lang.Boolean logS3AccessLogs) {
            this.props.logS3AccessLogs(logS3AccessLogs);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdas3.LambdaToS3 build() {
            return new software.amazon.awsconstructs.services.lambdas3.LambdaToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
